API Reference
=============

This section contains detailed API documentation for all modules.

.. toctree::
   :maxdepth: 2

   pipeline
   batch

Core Modules
------------

.. autosummary::
   :toctree: _autosummary
   :recursive:

   meeg_utils.preprocessing
